@@ -20,7 +20,7 @@ void SPVM_OPCODE_BUILDER_push_unresolved_goto_end_of_eval_or_end_of_method_on_ex
   int32_t line
 );
 
-int32_t SPVM_OPCODE_BUILDER_get_call_stack_index(SPVM_COMPILER* compiler, SPVM_OP* op);
+int32_t SPVM_OPCODE_BUILDER_get_runtime_var_index(SPVM_COMPILER* compiler, SPVM_OP* op);
 
 SPVM_OP* SPVM_OPCODE_BUILDER_get_returned_op_var(SPVM_COMPILER* compiler, SPVM_OP* op);
 
