@@ -51,16 +51,6 @@ SPVM::ByteList - Dynamic byte Array
 
 C<ByteList> is a dynamic C<byte> array.
 
-=head1 Enumerations
-
-  enum {
-    DEFAULT_CAPACITY = 4,
-  }
-
-=head2 DEFAULT_CAPACITY
-
-The default capacity. The value is 4.
-
 =head1 Fields
 
 =head2 capacity
@@ -98,7 +88,7 @@ C<static method new_len : L<ByteList|SPVM::ByteList> ($length : int, $capacity :
 
 Creates a new C<ByteList> object with $length and $capacity.
 
-If $capacity is less than 0, the capacity is set to the value of L</"DEFAULT_CAPACITY">.
+If $capacity is less than 0, the capacity is set to the default value.
 
 If $length is greater than $capacity, $capacity is set to $length.
 
@@ -208,18 +198,6 @@ $index must be greater than or equal to 0. Otherwise an exception is thrown.
 
 $index must be less than the length of $list.
 
-=head2 set_array
-
-C<method set_array : void ($array : byte[]);>
-
-Sets an $array. Each element of $array is copied to the element of the list.
-
-Exceptions:
-
-$array must be defined. Otherwise an exception is thrown.
-
-The length of $array must be equal to the length of $list.
-
 =head2 shift
 
 C<method shift : int ();>
